Learn R Programming

JSDNE (version 4.6)

A_PCR_result: Estimating the age using A_PCR method

Description

A_PCR method is the principal component linear regression analysis with Southeast Asian (A_PCR) method using the Dirichlet Normal Energy (DNE). The function automatically calculates the DNE on the auricular surface It provides the estimated age and standard errors (SE, 9.0yrs).

Usage

A_PCR_result(x, y)

Value

estimated result gets printed to the console

Arguments

x

the name of inputted ply file of the whole auricular surface

y

the name of inputted ply file of the apex of the auricular surface